model HeatTransferFhf
  import Modelica.SIunits.*;
  parameter Modelica.SIunits.Mass mO = 0.2;
  parameter Modelica.SIunits.Mass mW = 0.6;
  model WaermetauscherGliedFhf
    parameter Mass mOel = 1 "Masse Öl pro Element";
    parameter Mass mWasser = 2 "Masse Wasser pro Element";
    parameter Real koel = 400 "Wärmekonvektion Öl - Wand";
    parameter Real kwasser = 2000 "Wärmekonvektion Wasser - Wand";
    parameter ThermalConductance Gwand = 5000 "Wärmeleitung Wand";
    parameter Temperature Toel0 = 360 "Anfangstemperatur des Öls";
    parameter Temperature Twasser0 = 290 "Anfangstemperatur des Wassers";
    Modelica.Thermal.HeatTransfer.Components.Convection convection1 annotation(Placement(visible = true, transformation(origin = {-31.339,31.9088}, extent = {{-12,12},{12,-12}}, rotation = -90)));
    Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalconductor2(G = Gwand) annotation(Placement(visible = true, transformation(origin = {-31.339,3.7037}, extent = {{-12,12},{12,-12}}, rotation = -90)));
    Modelica.Thermal.HeatTransfer.Components.Convection convection2 annotation(Placement(visible = true, transformation(origin = {-31.339,-24.7863}, extent = {{-12,12},{12,-12}}, rotation = -90)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe heatedpipe1(h_g = 0, medium = Wasser, m = mOel, T0 = Toel0, tapT = 0, V_flowLaminar = 0.1, dpLaminar = 0.1, V_flowNominal = 1, dpNominal = 1) annotation(Placement(visible = true, transformation(origin = {-31.5938,64.8801}, extent = {{-10,-10},{10,10}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.HeatedPipe heatedpipe2(h_g = 0, medium = Wasser, m = mWasser, T0 = Twasser0, tapT = 0, V_flowLaminar = 0.1, dpLaminar = 0.1, V_flowNominal = 1, dpNominal = 1) annotation(Placement(visible = true, transformation(origin = {-31.3117,-59.2384}, extent = {{-10,10},{10,-10}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowport_a1 annotation(Placement(visible = true, transformation(origin = {-99.5769,45.4161}, extent = {{-10,-10},{10,10}}, rotation = 0), iconTransformation(origin = {-100.423,23.6953}, extent = {{-10,-10},{10,10}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowport_a2 annotation(Placement(visible = true, transformation(origin = {-100.423,-40.6206}, extent = {{-10,-10},{10,10}}, rotation = 0), iconTransformation(origin = {-100.423,-40.6206}, extent = {{-10,-10},{10,10}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowport_b1 annotation(Placement(visible = true, transformation(origin = {99.859,45.4161}, extent = {{-10,-10},{10,10}}, rotation = 0), iconTransformation(origin = {64.598,63.7518}, extent = {{-10,-10},{10,10}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowport_b2 annotation(Placement(visible = true, transformation(origin = {100.423,-40.3385}, extent = {{-10,-10},{10,10}}, rotation = 0), iconTransformation(origin = {100.423,-40.3385}, extent = {{-10,-10},{10,10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant constant2(k = kwasser) annotation(Placement(visible = true, transformation(origin = {5.12821,-24.7863}, extent = {{-12,12},{12,-12}}, rotation = -180)));
    Modelica.Blocks.Sources.Constant constant1(k = koel) annotation(Placement(visible = true, transformation(origin = {6.23686,32.1909}, extent = {{-12,12},{12,-12}}, rotation = -180)));
    annotation(Diagram(), Icon(graphics = {Rectangle(rotation = 0, lineColor = {0,0,0}, fillColor = {255,0,0}, pattern = LinePattern.Solid, fillPattern = FillPattern.Solid, lineThickness = 0.25, extent = {{-100,70.0855},{-36.1823,25.9259}}),Rectangle(rotation = 0, lineColor = {0,0,0}, fillColor = {255,85,0}, pattern = LinePattern.Solid, fillPattern = FillPattern.Solid, lineThickness = 0.25, extent = {{-37.037,70.0855},{27.9202,25.9259}}),Rectangle(rotation = 0, lineColor = {0,0,0}, fillColor = {255,255,0}, pattern = LinePattern.Solid, fillPattern = FillPattern.Solid, lineThickness = 0.25, extent = {{27.9202,70.0855},{100,25.9259}}),Rectangle(rotation = 0, lineColor = {0,0,0}, fillColor = {0,255,255}, pattern = LinePattern.Solid, fillPattern = FillPattern.Solid, lineThickness = 0.25, extent = {{-100,-18.8034},{-35.8974,-63.2479}}),Rectangle(rotation = 0, lineColor = {0,0,0}, fillColor = {0,170,255}, pattern = LinePattern.Solid, fillPattern = FillPattern.Solid, lineThickness = 0.25, extent = {{-35.8974,-18.8034},{26.4957,-63.2479}}),Rectangle(rotation = 0, lineColor = {0,0,0}, fillColor = {0,0,255}, pattern = LinePattern.Solid, fillPattern = FillPattern.Solid, lineThickness = 0.25, extent = {{26.4957,-18.8034},{100,-63.2479}}),Line(points = {{-56.9801,21.6524},{-56.9801,-11.1111}}, rotation = 0, color = {255,0,0}, pattern = LinePattern.Solid, thickness = 5.25, smooth = Smooth.Bezier),Line(points = {{-5.41311,21.0826},{-5.41311,-10.8262}}, rotation = 0, color = {255,0,0}, pattern = LinePattern.Solid, thickness = 5.25, smooth = Smooth.Bezier),Line(points = {{47.5783,20.5128},{47.5783,-11.396}}, rotation = 0, color = {255,0,0}, pattern = LinePattern.Solid, thickness = 5.25, smooth = Smooth.Bezier)}));
  equation
    connect(constant1.y,convection1.Gc) annotation(Line(points = {{-6.96314,32.1909},{-18.8034,32.1909},{-18.8034,31.9088},{-19.339,31.9088}}));
    connect(constant2.y,convection2.Gc) annotation(Line(points = {{-8.07179,-24.7863},{-18.8034,-24.7863},{-18.8034,-24.7863},{-19.339,-24.7863}}));
    connect(flowport_b2,heatedpipe2.flowPort_b) annotation(Line(points = {{100.423,-40.3385},{40.6206,-40.3385},{40.6206,-59.5205},{-21.4386,-59.5205},{-21.4386,-59.5205}}));
    connect(flowport_a2,heatedpipe2.flowPort_a) annotation(Line(points = {{-100.423,-40.6206},{-69.1114,-40.6206},{-69.1114,-59.2384},{-41.4669,-59.2384},{-41.4669,-59.2384}}));
    connect(heatedpipe1.flowPort_b,flowport_b1) annotation(Line(points = {{-21.5938,64.8801},{52.7504,64.8801},{52.7504,45.4161},{100.141,45.4161},{100.141,45.4161}}));
    connect(heatedpipe1.flowPort_a,flowport_a1) annotation(Line(points = {{-41.5938,64.8801},{-68.8293,64.8801},{-68.8293,44.8519},{-99.2948,44.8519},{-99.2948,44.8519}}));
    connect(convection2.fluid,heatedpipe2.heatPort) annotation(Line(points = {{-31.339,-36.7863},{-31.339,-49.0832},{-31.3117,-49.0832},{-31.3117,-49.0832}}));
    connect(heatedpipe1.heatPort,convection1.solid) annotation(Line(points = {{-31.5938,54.8801},{-31.5938,54.8801},{-31.5938,44.2877},{-31.5938,44.2877}}));
    connect(thermalconductor2.port_b,convection2.solid) annotation(Line(points = {{-31.339,-8.2963},{-31.0541,-8.2963},{-31.0541,-12.7863},{-31.339,-12.7863}}));
    connect(convection1.fluid,thermalconductor2.port_a) annotation(Line(points = {{-31.339,19.9088},{-31.339,19.9088},{-31.339,15.7037},{-31.339,15.7037}}));
  end WaermetauscherGliedFhf;
  annotation(experiment(StartTime = 0.0, StopTime = 30.0, Tolerance = 0.000001));
  HeatTransferFhf.WaermetauscherGliedFhf waermetauschergliedfhf1(mOel = mO, mWasser = mW) annotation(Placement(visible = true, transformation(origin = {-48.6409,11.731}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  HeatTransferFhf.WaermetauscherGliedFhf waermetauschergliedfhf2(mOel = mO, mWasser = mW) annotation(Placement(visible = true, transformation(origin = {-17.1674,11.731}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  HeatTransferFhf.WaermetauscherGliedFhf waermetauschergliedfhf3(mOel = mO, mWasser = mW) annotation(Placement(visible = true, transformation(origin = {13.1617,12.0171}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  HeatTransferFhf.WaermetauscherGliedFhf waermetauschergliedfhf4(mOel = mO, mWasser = mW) annotation(Placement(visible = true, transformation(origin = {42.3462,12.3033}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  HeatTransferFhf.WaermetauscherGliedFhf waermetauschergliedfhf5(mOel = mO, mWasser = mW) annotation(Placement(visible = true, transformation(origin = {70.9585,12.3033}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  HeatTransferFhf.WaermetauscherGliedFhf waermetauschergliedfhf6(mOel = mO, mWasser = mW) annotation(Placement(visible = true, transformation(origin = {-79.2561,11.4449}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient1(constantAmbientPressure = 100000.0, constantAmbientTemperature = 360, medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-138.598,16.0572}, extent = {{10,-10},{-10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeflow1(constantVolumeFlow = 0.0002, medium = Wasser, m = 0.1, T0 = 360) annotation(Placement(visible = true, transformation(origin = {-109.173,16.309}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeflow2(constantVolumeFlow = 0.00035, medium = Wasser, m = 0.1, T0 = 290) annotation(Placement(visible = true, transformation(origin = {107.033,-13.7797}, extent = {{10,-10},{-10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient2(constantAmbientPressure = 0, constantAmbientTemperature = 293.15, medium = Wasser) annotation(Placement(visible = true, transformation(origin = {105.751,16.9843}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient3(constantAmbientPressure = 100000.0, constantAmbientTemperature = 290, medium = Wasser) annotation(Placement(visible = true, transformation(origin = {137.156,-13.7797}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient4(constantAmbientPressure = 0, constantAmbientTemperature = 293.15, medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-134.204,-12.063}, extent = {{10,-10},{-10,10}}, rotation = 0)));
  constant Modelica.Thermal.FluidHeatFlow.Media.Water Wasser annotation(Placement(visible = true, transformation(origin = {44.1431,71.9199}, extent = {{-10,-10},{10,10}}, rotation = 0)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TO5(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {28.3262,34.907}, extent = {{-10,-10},{10,10}}, rotation = 90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TO6(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {56.3662,35.1931}, extent = {{-10,-10},{10,10}}, rotation = 90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TO3(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-33.4764,34.907}, extent = {{-10,-10},{10,10}}, rotation = 90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TW1(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-95.8512,-14.02}, extent = {{-10,-10},{10,10}}, rotation = -90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TW2(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-63.8054,-12.5894}, extent = {{-10,-10},{10,10}}, rotation = -90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TW3(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-33.4764,-12.8755}, extent = {{-10,-10},{10,10}}, rotation = -90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TW4(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-1.71674,-14.02}, extent = {{-10,-10},{10,10}}, rotation = -90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TW5(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {28.8984,-14.3062}, extent = {{-10,-10},{10,10}}, rotation = -90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TW6(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {55.5079,-14.3062}, extent = {{-10,-10},{10,10}}, rotation = -90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TO4(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-1.43062,35.7654}, extent = {{-10,-10},{10,10}}, rotation = 90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TO1(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-94.9928,36.3377}, extent = {{-10,-10},{10,10}}, rotation = 90)));
  Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor TO2(medium = Wasser) annotation(Placement(visible = true, transformation(origin = {-64.3776,35.7654}, extent = {{-10,-10},{10,10}}, rotation = 90)));
equation
  connect(TW6.flowPort,waermetauschergliedfhf5.flowport_a2) annotation(Line(points = {{55.5079,-4.3062},{55.5079,8.29757},{60.6581,8.29757},{60.6581,8.29757}}));
  connect(TW5.flowPort,waermetauschergliedfhf4.flowport_a2) annotation(Line(points = {{28.8984,-4.3062},{28.8984,8.29757},{32.618,8.29757},{32.618,8.29757}}));
  connect(TW4.flowPort,waermetauschergliedfhf3.flowport_a2) annotation(Line(points = {{-1.71674,-4.02},{-1.71674,7.72532},{2.86123,7.72532},{2.86123,7.72532}}));
  connect(TW3.flowPort,waermetauschergliedfhf2.flowport_a2) annotation(Line(points = {{-33.4764,-2.8755},{-33.4764,8.01144},{-28.0401,8.01144},{-28.0401,8.01144}}));
  connect(TW2.flowPort,waermetauschergliedfhf1.flowport_a2) annotation(Line(points = {{-63.8054,-2.5894},{-63.8054,7.4392},{-59.2275,7.4392},{-59.2275,7.4392}}));
  connect(TW1.flowPort,waermetauschergliedfhf6.flowport_a2) annotation(Line(points = {{-95.8512,-4.02},{-95.8512,7.4392},{-89.5565,7.4392},{-89.5565,7.4392}}));
  connect(TO6.flowPort,waermetauschergliedfhf5.flowport_a1) annotation(Line(points = {{56.3662,25.1931},{56.3662,16.8813},{60.9442,16.8813},{60.9442,16.8813}}));
  connect(TO5.flowPort,waermetauschergliedfhf4.flowport_a1) annotation(Line(points = {{28.3262,24.907},{28.3262,16.5951},{32.9041,16.5951},{32.9041,16.5951}}));
  connect(TO4.flowPort,waermetauschergliedfhf3.flowport_a1) annotation(Line(points = {{-1.43062,25.7654},{-1.43062,16.309},{3.14735,16.309},{3.14735,16.309}}));
  connect(TO3.flowPort,waermetauschergliedfhf2.flowport_a1) annotation(Line(points = {{-33.4764,24.907},{-33.4764,16.309},{-27.1817,16.309},{-27.1817,16.309}}));
  connect(TO2.flowPort,waermetauschergliedfhf1.flowport_a1) annotation(Line(points = {{-64.3776,25.7654},{-64.3776,16.0229},{-59.2275,16.0229},{-59.2275,16.0229}}));
  connect(TO1.flowPort,waermetauschergliedfhf6.flowport_a1) annotation(Line(points = {{-94.9928,26.3377},{-94.9928,16.309},{-89.2704,16.309},{-89.2704,16.309}}));
  connect(ambient4.flowPort,waermetauschergliedfhf6.flowport_a2) annotation(Line(points = {{-124.204,-12.063},{-113.019,-12.063},{-113.019,7.4392},{-89.5565,7.4392},{-89.5565,7.4392}}));
  connect(volumeflow2.flowPort_b,waermetauschergliedfhf5.flowport_b2) annotation(Line(points = {{97.0329,-13.7797},{89.7282,-13.7797},{89.7282,8.3319},{81.3963,8.3319},{81.3963,8.3319}}));
  connect(ambient3.flowPort,volumeflow2.flowPort_a) annotation(Line(points = {{127.156,-13.7797},{117.288,-13.7797},{117.288,-13.7797},{117.033,-13.7797}}));
  connect(waermetauschergliedfhf5.flowport_b1,ambient2.flowPort) annotation(Line(points = {{80.9444,16.8449},{91.9714,16.8449},{95.7511,17.3047},{95.7511,16.9843}}));
  connect(volumeflow1.flowPort_b,waermetauschergliedfhf6.flowport_a1) annotation(Line(points = {{-99.1731,16.309},{-89.0873,16.309},{-89.0873,15.7024},{-89.0873,15.7024}}));
  connect(ambient1.flowPort,volumeflow1.flowPort_a) annotation(Line(points = {{-128.598,16.0572},{-118.89,16.0572},{-118.89,15.382},{-118.89,15.382}}));
  connect(waermetauschergliedfhf6.flowport_b2,waermetauschergliedfhf1.flowport_a2) annotation(Line(points = {{-69.2138,7.41107},{-59.2275,7.41107},{-59.2275,7.66899},{-58.6832,7.66899}}));
  connect(waermetauschergliedfhf6.flowport_b1,waermetauschergliedfhf1.flowport_a1) annotation(Line(points = {{-69.2702,15.9865},{-58.6552,15.9865},{-58.6552,16.2727},{-58.5986,16.2727}}));
  connect(waermetauschergliedfhf4.flowport_b2,waermetauschergliedfhf5.flowport_a2) annotation(Line(points = {{52.3885,8.26944},{60.6581,8.26944},{60.9442,8.24123},{60.9162,8.24123}}));
  connect(waermetauschergliedfhf4.flowport_b1,waermetauschergliedfhf5.flowport_a1) annotation(Line(points = {{52.3321,16.8449},{60.6581,16.8449},{60.372,17.4171},{61.0008,16.8449}}));
  connect(waermetauschergliedfhf3.flowport_b2,waermetauschergliedfhf4.flowport_a2) annotation(Line(points = {{23.204,7.9833},{31.7597,7.9833},{31.7597,8.24123},{32.3039,8.24123}}));
  connect(waermetauschergliedfhf3.flowport_b1,waermetauschergliedfhf4.flowport_a1) annotation(Line(points = {{23.1476,16.5588},{32.3319,16.5588},{32.3319,16.8449},{32.3885,16.8449}}));
  connect(waermetauschergliedfhf2.flowport_b2,waermetauschergliedfhf3.flowport_a2) annotation(Line(points = {{-7.12508,7.6972},{2.86123,7.6972},{2.86123,7.95509},{3.11936,7.95509}}));
  connect(waermetauschergliedfhf2.flowport_b1,waermetauschergliedfhf3.flowport_a1) annotation(Line(points = {{-7.18148,16.2727},{3.14735,16.2727},{3.14735,16.5588},{3.20397,16.5588}}));
  connect(waermetauschergliedfhf1.flowport_b2,waermetauschergliedfhf2.flowport_a2) annotation(Line(points = {{-38.5986,7.6972},{-28.0401,7.6972},{-28.0401,7.66899},{-27.2097,7.66899}}));
  connect(waermetauschergliedfhf1.flowport_b1,waermetauschergliedfhf2.flowport_a1) annotation(Line(points = {{-38.655,16.2727},{-27.4678,16.2727},{-27.4678,16.2727},{-27.1251,16.2727}}));
end HeatTransferFhf;
